@@ -15,8 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 import unittest
 
 
@@ -24,9 +22,12 @@ def test_suite():
     names = [
         'debian',
         'debian_lintian',
+        'debian_upstream',
         'proposal',
+        'publish',
         'run',
         'utils',
+        'version',
         ]
     module_names = [__name__ + '.test_' + name for name in names]
     loader = unittest.TestLoader()
